Coverage report

# Coverage report: 84%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 607 | 98 | 0 | 84%
src/hatch_ci/__init__.py | 3 | 1 | 0 | 67%
src/hatch_ci/cli.py | 73 | 11 | 0 | 85%
src/hatch_ci/common.py | 2 | 2 | 0 | 0%
src/hatch_ci/hooks.py | 6 | 6 | 0 | 0%
src/hatch_ci/scm.py | 173 | 13 | 0 | 92%
src/hatch_ci/script.py | 72 | 11 | 0 | 85%
src/hatch_ci/tools.py | 237 | 13 | 0 | 95%
src/hatch_ci/version_hook.py | 41 | 41 | 0 | 0%

No items found using the specified filter.